<?php
/*
Plugin Name: Del-Post-Rev
Plugin URI:  http://keksus.com/dpr.html
Description: Delete post revisions and disable revisions
Version:     1.0
Author:      Keksus
Author URI:  http://keksus.com/
License:     GPLv3

Copyright 2018-2019 Keksus.com (email : alexbalance@gmail.com)
*/ 

if(!defined('ABSPATH')) die;

global $dpr_option_name, $dpr_options;
$dpr_option_name = 'dpr';
$dpr_options = get_option($dpr_option_name);

register_activation_hook( __FILE__, 'dpr_activate' );
register_deactivation_hook( __FILE__, 'dpr_deactivate' );

function dpr_activate() {
    global $dpr_option_name, $dpr_options;

    $data = array(
        'disable' => null
    );
    update_option( $dpr_option_name, $data );

    $notice =  __( 'Thank you for installing this plugin! Plugin settings are available on the page', 'dpr_activate_notice' ) .
                      ' <a href="' . admin_url( 'options-general.php?page=dpr_settings' ). '">Settings - Del-Post-Rev</a>';
    update_option( 'dpr_activate_notice', $notice );
}

function dpr_activate_notice() {
    if( $notice = get_option( 'dpr_activate_notice' ) ) {
        echo "<div class='updated'><p>$notice</p></div>";
    }
    delete_option( 'dpr_activate_notice' );
}
add_action( 'admin_notices', 'dpr_activate_notice' );

function dpr_deactivate() {
    global $dpr_option_name;
    delete_option( $dpr_option_name );
}

// show plugin footer text
function dpr_this_screen() {
    if( get_current_screen()->id === "settings_page_dpr_settings" ) {
        add_filter( 'update_footer', 'dpr_right_admin_footer_text', 11); 
        function dpr_right_admin_footer_text( $text ) {
            $text = current_time( 'Y-m-d' );
            return $text;
        }
        add_filter( 'admin_footer_text', 'dpr_left_admin_footer_text' ); 
        function dpr_left_admin_footer_text( $text ) {
            $text = __( 'Thank you for installing this plugin! Created by', 'dpr' ).' <a class="created" href="http://keksus.com">Keksus</a>';
            return $text;
        }
    }
}
add_action( 'current_screen', 'dpr_this_screen' );

function dpr_scripts_admin() {
    if ( get_current_screen()->id === "settings_page_dpr_settings" ) {
        wp_enqueue_style( 'admin-css',   plugins_url( 'css/admin.css',__FILE__ ) );
        wp_enqueue_script( 'admin-js',   plugins_url( 'js/admin.js',__FILE__ ), array(jquery) );
    }
}
add_action( 'admin_enqueue_scripts', 'dpr_scripts_admin' );

function dpr_admin_page_settings() {
    add_options_page('Del-Post-Rev', 'Del-Post-Rev', 'edit_pages', 'dpr_settings', 'dpr_admin_page');
}
add_action('admin_menu', 'dpr_admin_page_settings');

// register plugin settings
function dpr_plugin_settings() {
    global $dpr_option_name, $dpr_options;
    register_setting( 'dpr_settings', $dpr_option_name, 'dpr_sanitize' );
}
add_action( 'admin_init', 'dpr_plugin_settings' );

function dpr_admin_page() {
    global $wpdb, $dpr_option_name, $dpr_options, $revisions;
    $revisions = $wpdb->get_results("SELECT count(*) as count FROM $wpdb->posts WHERE post_type = 'revision' ");
?>
<div class='options'>
    <h1><?php _e( 'Del-Post-Rev Settings', 'dpr' ); ?></h1>
    <form class='dpr-form' method='POST' action="options.php" >
    <?php settings_fields( 'dpr_settings' ); ?>
        <div class='q12'>
            <div class='tabs'>
                <ul class='tab-links'>
                    <li class='active'><a href='#tab1'><?php _e( 'Settings', 'dpr' ); ?></a></li>
                    <li><a href='#tab2'><?php _e( 'Info', 'dpr' ); ?></a></li>                  
                </ul>
            </div>
            <div class='tab-content active'>
                <div id='tab1' class='tab active'>
                    <div class='clear'>
                        <div class='q8'>
                            <div class='post'>
                                <h5>You have <strong><?php echo ($_POST['dpr_submit']) ? "0" : $revisions[0]->count; ?></strong> post revisions</h5>
                                <br>                       
                            </div>
                        </div>
                    </div>
                    <div class='clear'>
					<?php if($revisions[0]->count > 0): ?>
						<input type="submit" class='button-primary' name="dpr_submit" value="Delete post revisions" />
					<?php endif; ?>
					
                </div>
                </div>
                <div id='tab2' class='tab'>
                    <div class='clear'>
                        <div class='q8'>
                            <div class='post'>
                                <h2><?php _e( 'License:', 'dpr' ); ?></h2>
                                    <p><?php _e( 'This plugin is licensed under the', 'dpr' );?>
                                        <a target="_blank" href="https://www.gnu.org/licenses/gpl-3.0.html">GPL v3 license</a>
                                    <?php _e( 'This means you can use it for anything you like as long as it remains GPL v3.', 'dpr' ); ?></p>
                                <h2><?php _e( 'Recommended Plugins:', 'dpr' ); ?></h2>
                                <ul>
                                    <li><span>Simple contact form: </span> 
                                        <a target="_blank" href="https://wordpress.org/plugins/ajax-message/">Ajax message</a>
                                    </li>
                                    <li><span>Shortcodes with CSS grid: </span> 
                                        <a target="_blank" href="https://wordpress.org/plugins/q-shortcodes/">q-Shortcodes</a>
                                    </li>								
									<li><span>Export and import Customizer settings: </span> 
                                        <a target="_blank" href="https://wordpress.org/plugins/customizer-ex/">Customizer EX</a>
                                    </li>
                                </ul>
                                <h2><?php _e( 'Links:', 'dpr' ); ?></h2>
                                    <p><?php _e( 'This plugin was created by', 'dpr' );?>
                                        <a target="_blank" href="http://keksus.com/">Keksus.com</a> <?php _e( 'You can follow us via our social media!', 'dpr' ); ?>
                                    </p>
                                    <p class='links'>
                                        <a target="_blank" href="https://twitter.com/keks5588" class="button button-secondary">Twitter</a>
                                        <a target="_blank" href="https://www.facebook.com/keks5588" class="button button-secondary">Facebook</a>
                                        <a target="_blank" href="https://www.instagram.com/keksus55/" class="button button-secondary">Instagram</a>
                                    </p>

                                <h2><?php _e( 'Donation:', 'dpr' ); ?></h2>
                                <p><?php _e( 'If you would like this plugin, you can donate any amount for other plugins development.', 'dpr' ); ?></p>
                                <p class='links'><a href="http://keksus.com/donate.html" target="_blank" class="button button-secondary">
                                    <?php _e( 'Donate', 'dpr' ); ?>
                                    </a>
                                </p>
                            </div><!-- end post -->
                        </div>
                    </div>      
                </div>
                
            </div>
        </div>
    </form>
</div>
<?php
} // dpr_admin_page

// delete revisions
if(isset($_POST['dpr_submit'])) {
    $wpdb->query("
        DELETE p,tr,pm 
        FROM $wpdb->posts p 
        LEFT JOIN $wpdb->term_relationships tr ON p.ID = tr.object_id 
        LEFT JOIN $wpdb->postmeta pm ON p.ID = pm.post_id 
        WHERE p.post_type = 'revision'
    ");                     
}

// clean options and show message
function dpr_sanitize($dpr_options) {  
    $dpr_type = 'updated';
    $dpr_message = __( 'Settings saved!', 'dpr' );
    add_settings_error( $dpr_option_name, 'settings_updated', $dpr_message, $dpr_type );
	return $dpr_options; 
}

